@@ -1,7 +1,6 @@
 { package Catalyst::Action::SOAP::DocumentLiteral;
 
   use base qw/Catalyst::Action::SOAP/;
-  use constant NS_SOAP_ENV => "http://schemas.xmlsoap.org/soap/envelope/";
 
   sub execute {
       my $self = shift;
@@ -10,8 +9,7 @@
       $self->prepare_soap_xml_post($c);
       unless ($c->stash->{soap}->fault) {
           my $envelope = $c->stash->{soap}->parsed_envelope;
-          my $namespace = $c->stash->{soap}->namespace || NS_SOAP_ENV;
-          my ($body) = $envelope->getElementsByTagNameNS($namespace, 'Body');
+          my ($body) = $envelope->getElementsByTagName('Body',0);
           $self->NEXT::execute($controller, $c, $body);
       }
   }
